==> truffle-api-22.2.0-sources.jar: com/oracle/truffle/api/strings/InternalErrors.java <==
/*
 * Copyright (c) 2021, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * The Universal Permissive License (UPL), Version 1.0
 *
 * Subject to the condition set forth below, permission is hereby granted to any
 * person obtaining a copy of this software, associated documentation and/or
 * data (collectively the "Software"), free of charge and under any and all
 * copyright rights in the Software, and any and all patent rights owned or
 * freely licensable by each licensor hereunder covering either (i) the
 * unmodified Software as contributed to or provided by such licensor, or (ii)
 * the Larger Works (as defined below), to deal in both
 *
 * (a) the Software, and
 *
 * (b) any piece of software and/or hardware listed in the lrgrwrks.txt file if
 * one is included with the Software each a "Larger Work" to which the Software
 * is contributed by such licensors),
 *
 * without restriction, including without limitation the rights to copy, create
 * derivative works of, display, perform, and distribute the Software and make,
 * use, sell, offer for sale, import, export, have made, and have sold the
 * Software and the Larger Work(s), and to sublicense the foregoing rights on
 * either these or other terms.
 *
 * This license is subject to the following condition:
 *
 * The above copyright notice and either this complete permission notice or at a
 * minimum a reference to the UPL must be included in all copies or substantial
 * portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.oracle.truffle.api.strings;

import com.oracle.truffle.api.CompilerDirectives;
import com.oracle.truffle.api.CompilerDirectives.TruffleBoundary;
import com.oracle.truffle.api.TruffleLanguage;

final class InternalErrors {

    static RuntimeException substringOutOfBounds() {
        CompilerDirectives.transferToInterpreterAndInvalidate();
        return new IndexOutOfBoundsException("substring range (offset + length) is out of bounds!");
    }

    static RuntimeException indexOutOfBounds() {
        CompilerDirectives.transferToInterpreterAndInvalidate();
        return new IndexOutOfBoundsException("index is out of bounds!");
    }

    static RuntimeException invalidCodePoint(int c) {
        CompilerDirectives.transferToInterpreterAndInvalidate();
        return new IllegalArgumentException(String.format("invalid code point: 0x%x", c));
    }

    static RuntimeException unsupportedOperation() {
        CompilerDirectives.transferToInterpreterAndInvalidate();
        return new UnsupportedOperationException();
    }

    static RuntimeException unsupportedOperation(String msg) {
        CompilerDirectives.transferToInterpreterAndInvalidate();
        return new UnsupportedOperationException(msg);
    }

    static RuntimeException illegalArgument(String msg) {
        CompilerDirectives.transferToInterpreterAndInvalidate();
        return new IllegalArgumentException(msg);
    }

    static RuntimeException illegalState(String msg) {
        CompilerDirectives.transferToInterpreterAndInvalidate();
        return new IllegalStateException(msg);
    }

    static RuntimeException wrongEncoding(TruffleString.Encoding expectedEncoding) {
        CompilerDirectives.transferToInterpreterAndInvalidate();
        return new IllegalArgumentException("the given string is not compatible to the expected encoding \"" + expectedEncoding + "\", did you forget to convert it?");
    }

    static RuntimeException unknownEncoding(String name) {
        CompilerDirectives.transferToInterpreterAndInvalidate();
        return illegalArgument("unknown encoding: \"" + name + "\"");
    }

    /**
     * Thrown when an operation requires native access but
     * {@link TruffleLanguage.Env#isNativeAccessAllowed()} is {@code false}.
     */
    public static RuntimeException nativeAccessRequired() {
        CompilerDirectives.transferToInterpreterAndInvalidate();
        return new UnsupportedOperationException("this operation requires native access!");
    }

    @TruffleBoundary
    static OutOfMemoryError outOfMemory() {
        return new OutOfMemoryError();
    }
}

==> truffle-api-23.0.1-sources.jar: com/oracle/truffle/api/strings/InternalErrors.java <==
/*
 * Copyright (c) 2021, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * The Universal Permissive License (UPL), Version 1.0
 *
 * Subject to the condition set forth below, permission is hereby granted to any
 * person obtaining a copy of this software, associated documentation and/or
 * data (collectively the "Software"), free of charge and under any and all
 * copyright rights in the Software, and any and all patent rights owned or
 * freely licensable by each licensor hereunder covering either (i) the
 * unmodified Software as contributed to or provided by such licensor, or (ii)
 * the Larger Works (as defined below), to deal in both
 *
 * (a) the Software, and
 *
 * (b) any piece of software and/or hardware listed in the lrgrwrks.txt file if
 * one is included with the Software each a "Larger Work" to which the Software
 * is contributed by such licensors),
 *
 * without restriction, including without limitation the rights to copy, create
 * derivative works of, display, perform, and distribute the Software and make,
 * use, sell, offer for sale, import, export, have made, and have sold the
 * Software and the Larger Work(s), and to sublicense the foregoing rights on
 * either these or other terms.
 *
 * This license is subject to the following condition:
 *
 * The above copyright notice and either this complete permission notice or at a
 * minimum a reference to the UPL must be included in all copies or substantial
 * portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package com.oracle.truffle.api.strings;

import com.oracle.truffle.api.CompilerDirectives;
import com.oracle.truffle.api.CompilerDirectives.TruffleBoundary;
import com.oracle.truffle.api.TruffleLanguage;

final class InternalErrors {

    static RuntimeException substringOutOfBounds() {
        CompilerDirectives.transferToInterpreterAndInvalidate();
        return new IndexOutOfBoundsException("substring range (offset + length) is out of bounds!");
    }

    static RuntimeException indexOutOfBounds() {
        CompilerDirectives.transferToInterpreterAndInvalidate();
        return new IndexOutOfBoundsException("index is out of bounds!");
    }

    static RuntimeException invalidCodePoint(int c) {
        CompilerDirectives.transferToInterpreterAndInvalidate();
        return new IllegalArgumentException(String.format("invalid code point: 0x%x", c));
    }

    static RuntimeException unsupportedOperation() {
        CompilerDirectives.transferToInterpreterAndInvalidate();
        return new UnsupportedOperationException();
    }

    static RuntimeException unsupportedOperation(String msg) {
        CompilerDirectives.transferToInterpreterAndInvalidate();
        return new UnsupportedOperationException(msg);
    }

    static RuntimeException illegalArgument(String msg) {
        CompilerDirectives.transferToInterpreterAndInvalidate();
        return new IllegalArgumentException(msg);
    }

    static RuntimeException illegalByteArrayLength(String msg) {
        CompilerDirectives.transferToInterpreterAndInvalidate();
        return new TruffleString.IllegalByteArrayLengthException(msg);
    }

    static RuntimeException illegalState(String msg) {
        CompilerDirectives.transferToInterpreterAndInvalidate();
        return new IllegalStateException(msg);
    }

    static RuntimeException wrongEncoding(TruffleString.Encoding expectedEncoding) {
        CompilerDirectives.transferToInterpreterAndInvalidate();
        return new IllegalArgumentException("the given string is not compatible to the expected encoding \"" + expectedEncoding + "\", did you forget to convert it?");
    }

    static RuntimeException unknownEncoding(String name) {
        CompilerDirectives.transferToInterpreterAndInvalidate();
        return illegalArgument("unknown encoding: \"" + name + "\"");
    }

    /**
     * Thrown when an operation requires native access but
     * {@link TruffleLanguage.Env#isNativeAccessAllowed()} is {@code false}.
     */
    public static RuntimeException nativeAccessRequired() {
        CompilerDirectives.transferToInterpreterAndInvalidate();
        return new UnsupportedOperationException("this operation requires native access!");
    }

    @TruffleBoundary
    static OutOfMemoryError outOfMemory() {
        return new OutOfMemoryError();
    }
}
